pub fn alpha_texture_descriptor(
width: u32,
height: u32,
) -> TextureDescriptor<'static>Expand description
The descriptor for an alpha texture of width x height texels.
pub fn alpha_texture_descriptor(
width: u32,
height: u32,
) -> TextureDescriptor<'static>The descriptor for an alpha texture of width x height texels.