#[repr(C, align(16))]pub struct GpuEncodedImage {
pub image_params: u32,
pub image_size: u32,
pub image_offset: u32,
pub transform: [f32; 6],
pub tint: u32,
pub tint_mode: u32,
pub image_padding: u32,
}Expand description
An encoded image paint.
Fields
image_params: u32Packed sampling quality, extend modes and atlas index:
bits 6-13 atlas_index, bits 4-5 extend_y, bits 2-3 extend_x,
bits 0-1 quality.
image_size: u32Packed image width and height.
image_offset: u32Offset of the image within the atlas texture, in pixels.
transform: [f32; 6]Transform matrix [a, b, c, d, tx, ty].
tint: u32Premultiplied tint color, packed as RGBA8 unorm.
tint_mode: u32Tint mode.
image_padding: u32Transparent padding pixels around the image in the atlas.
Implementations